@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 from pyg_encoders._parquet import pd_to_parquet, pd_read_parquet
 from pyg_encoders._encode import encode, decode
-from pyg_base import is_pd, is_dict, is_series, is_arr, is_date, dt2str, tree_items, dictable, try_value, dt, is_jsonable, is_primitive
+from pyg_base import is_pd, is_dict, is_series, is_arr, is_date, dt2str, tree_items, dictable, try_value, dt
 from pyg_npy import pd_to_npy, np_save, pd_read_npy, mkdir
 from pyg_base import Bi, bi_merge, is_bi, bi_read, try_none
 from functools import partial
@@ -22,6 +22,19 @@ _writer = 'writer'
 __all__ = ['root_path', 'pd_to_csv', 'pd_read_csv', 'parquet_encode', 'parquet_write', 'csv_encode', 'csv_write', 'pickle_dump', 'pickle_load', 'dictable_decode']
 
 
+# def encode(value):
+#     """
+#     encoder is similar to pyg_base.encoder with the only exception being that bson.objectid.ObjectId used by mongodb to generate the document _id, are not encoded
+
+#     Parameters
+#     ----------
+#     value : value/document to be encoded
+
+#     Returns
+#     -------
+#     encoded value/document
+#     """
+#     return encode_(value, ObjectId)
 
 def root_path(doc, root, fmt = None, **kwargs):
     """
@@ -223,16 +236,14 @@ def pickle_encode(value, path, asof = None):
         return res
     elif isinstance(value, (list, tuple)):
         return type(value)([pickle_encode(v, '%s/%i'%(path,i), asof) for i, v in enumerate(value)])
-    elif is_date(value) or is_primitive(value) or callable(value) or is_jsonable(value):
-        return value
     else:
-        try:
-            path = root_path_check(path)
-            path = path if path.endswith(_pickle) else path + _pickle
-            path = pickle_dump(value, path = path)
-            return dict(_obj = _pickle_load, path = path)
-        except pickle.PicklingError:
-            return value
+        return value ## we prefer 
+    # else:
+    #     path = root_path_check(path)
+    #     path = path if path.endswith(_pickle) else path + _pickle
+    #     path = pickle_dump(value, path = path)
+    #     return dict(_obj = _pickle_load, path = path)
+        
 
 pd_to_parquet_twice = try_value(pd_to_parquet, repeat = 2, sleep = 1, return_value = False)
 
